args property

List<String> args
final

A List of the parsed arguments from the command line.

Doesn't contain command identifiers or flags and their values at all.

Implementation

final List<String> args;