cmd property
The NatrixCommand which owns this callback and it's position in the cli tree after pipeline traversal.
Implementation
final NatrixCommand cmd;
The NatrixCommand which owns this callback and it's position in the cli tree after pipeline traversal.
final NatrixCommand cmd;