flags property
The flags of the command line input parsed from the predefined NatrixFlags of their corresponding NatrixCommand which got mapped in NatrixPipeline traversal.
Implementation
final Iterable<NatrixFlag> flags;
The flags of the command line input parsed from the predefined NatrixFlags of their corresponding NatrixCommand which got mapped in NatrixPipeline traversal.
final Iterable<NatrixFlag> flags;