NatrixChar class

Represents a single character string.

Annotations
  • @immutable

Constructors

NatrixChar(String c)

Properties

c String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator *(int times) String
operator +(String other) String
operator ==(Object other) bool
The equality operator.
override