NatrixColor enum
Definition of the corresponding ANSI escape sequence values for their colors.
Values
- none → const NatrixColor
-
const NatrixColor(-1) - grayDark → const NatrixColor
-
const NatrixColor(236) - gray → const NatrixColor
-
const NatrixColor(250) - grayAccent → const NatrixColor
-
const NatrixColor(244) - redDark → const NatrixColor
-
const NatrixColor(88) - red → const NatrixColor
-
const NatrixColor(210) - redAccent → const NatrixColor
-
const NatrixColor(196) - orangeDark → const NatrixColor
-
const NatrixColor(130) - orange → const NatrixColor
-
const NatrixColor(216) - orangeAccent → const NatrixColor
-
const NatrixColor(208) - yellowDark → const NatrixColor
-
const NatrixColor(136) - yellow → const NatrixColor
-
const NatrixColor(229) - yellowAccent → const NatrixColor
-
const NatrixColor(226) - greenDark → const NatrixColor
-
const NatrixColor(22) - green → const NatrixColor
-
const NatrixColor(120) - greenAccent → const NatrixColor
-
const NatrixColor(46) - cyanDark → const NatrixColor
-
const NatrixColor(30) - cyan → const NatrixColor
-
const NatrixColor(159) - cyanAccent → const NatrixColor
-
const NatrixColor(51) - blueDark → const NatrixColor
-
const NatrixColor(18) - blue → const NatrixColor
-
const NatrixColor(153) - blueAccent → const NatrixColor
-
const NatrixColor(21) - purpleDark → const NatrixColor
-
const NatrixColor(54) - purple → const NatrixColor
-
const NatrixColor(183) - purpleAccent → const NatrixColor
-
const NatrixColor(93) - pinkDark → const NatrixColor
-
const NatrixColor(125) - pink → const NatrixColor
-
const NatrixColor(218) - pinkAccent → const NatrixColor
-
const NatrixColor(201)
Properties
- ansiBackgroundSequence → String
-
no setter
- ansiForegroundSequence → String
-
no setter
- ansiResetBackgroundSequence → String
-
no setter
- ansiResetForegroundSequence → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
colorize(
String text) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NatrixColor> - A constant List of the values in this enum, in order of their declaration.