callback property
The function executed when this command is selected as the final target of pipeline resolution.
Implementation
final NatrixCommandCallback callback;
The function executed when this command is selected as the final target of pipeline resolution.
final NatrixCommandCallback callback;