children property
The sub-commands nested directly beneath this command inside pipeline traversal.
Implementation
final Iterable<NatrixCommand> children;
The sub-commands nested directly beneath this command inside pipeline traversal.
final Iterable<NatrixCommand> children;