parent property
During processing within NatrixPipeline, NatrixCommand will be added as a parent to a new instance, corresponding to its parent NatrixCommand in the CLI tree.
Implementation
final NatrixCommand? parent;
During processing within NatrixPipeline, NatrixCommand will be added as a parent to a new instance, corresponding to its parent NatrixCommand in the CLI tree.
final NatrixCommand? parent;