globalFlags property

Iterable<NatrixFlag> globalFlags
final

globalFlags is a Iterable with elements that may occur in parserOutput.args.

The usage of globalFlags is related to specify which flags are global to provide better help/usage-documentation for the user of the cli.

Implementation

final Iterable<NatrixFlag> globalFlags;