set abstract method

NatrixFlag<T> set(
  1. T value
)

Returns a new instance of this flag with the specified value.

Invoked internally to produce updated flag instances after parsing.

Implementation

NatrixFlag<T> set(T value);