NatrixParser class
The NatrixParser processes command-line input in a standard CLI syntax. This is the implementation of the user interface.
Constructors
- NatrixParser()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
mergeArguments(
List< String> rawArguments) → List<String> -
To process the arguments correctly, the system checks for quotation
marks in the arguments, as well as for opening and closing brackets,
to ensure that the
mergedArgumentscontain related data to actual parse it later. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
List< String> mergedArguments, Iterable<NatrixFlag> predefinedFlags) → NatrixParserOutput -
Reads
mergedArguments(by default from NatrixParser.mergeArguments()) and converts them into concrete, interface-compliant value representations. -
parseFlags(
List< String> mergedArguments, Iterable<NatrixFlag> predefinedFlags) → Iterable<NatrixFlag> -
Using the
predefinedFlags, it is possible to determine the corresponding NatrixFlag called from the input values (mergedArguments) and create a copy of the instance with the new value provided. -
parseRawFlag(
String raw, [String? val]) → NatrixParserFlag - Reads raw String input and map it into the description of a flag usable for further processing.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited