NatrixParserOutput class

NatrixParserOutput holds the output of the process within NatrixParser.

Constructors

NatrixParserOutput([List<String> args = const [], Iterable<NatrixFlag> flags = const []])
const

Properties

args List<String>
The args, that will be finally applied to a commands callback.
final
flags Iterable<NatrixFlag>
An Iterable of all NatrixFlags which will be applied to a command.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited