NatrixStyle enum
Definition of the corresponding ANSI escape sequence values for their styles.
Values
- none → const NatrixStyle
-
const NatrixStyle(-1, -1) - bold → const NatrixStyle
-
const NatrixStyle(1, 22) - italic → const NatrixStyle
-
const NatrixStyle(3, 23) - underline → const NatrixStyle
-
const NatrixStyle(4, 24) - blink → const NatrixStyle
-
const NatrixStyle(5, 25) - reverse → const NatrixStyle
-
const NatrixStyle(7, 27) -
const NatrixStyle(8, 28) - strikethrough → const NatrixStyle
-
const NatrixStyle(9, 29)
Properties
- ansiResetSequence → String
-
no setter
- ansiStartSequence → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - resetCode → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startCode → int
-
final
Methods
-
apply(
String text) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NatrixStyle> - A constant List of the values in this enum, in order of their declaration.