NatrixDefaultTheme class

Inheritance

Constructors

NatrixDefaultTheme.of(NatrixContext context, {int lineLength = 65})

Properties

commands NatrixBlock
commands is a section that lists applicable sub-NatrixCommands.
no setteroverride
context NatrixContext
The NatrixContext for the current execution of the NatrixPipeline.
finalinherited
flags NatrixBlock
flags is a section that lists applicable NatrixFlags.
no setteroverride
The footer is the footer of a help request regarding a command.
no setteroverride
globalFlags NatrixBlock
no setter
hashCode int
The hash code for this object.
no setterinherited
The header is the header of a helper request relating to a command.
no setteroverride
maxLineLength int
latefinal
root NatrixSection
The root is the NatrixSection that is to be formatted and displayed when a user either calls the application’s root command (provided this does not already have a function and would simply displays a motd) or when the root is accessed via the help command.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syntax NatrixSection
The syntax is the syntax of a single command, including all its associated elements.
no setteroverride
usage NatrixLine
The usage is usually a single line that briefly outlines the command's syntax.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited