footer property
The footer is the footer of a help request regarding a command.
Implementation
@override
NatrixSection get footer => NatrixLine(text: NatrixText.empty());
The footer is the footer of a help request regarding a command.
@override
NatrixSection get footer => NatrixLine(text: NatrixText.empty());