root property
The root is the NatrixSection that is to be formatted and displayed when a user either calls the application’s root command (provided this does not already have a function and would simply displays a motd) or when the root is accessed via the help command.
Implementation
@override
NatrixSection get root => syntax;