syntax property
The syntax is the syntax of a single command, including all its associated elements.
Implementation
@override
NatrixSection get syntax => throw UnimplementedError();
The syntax is the syntax of a single command, including all its associated elements.
@override
NatrixSection get syntax => throw UnimplementedError();