NatrixDocument class

Implemented types

Constructors

NatrixDocument({required NatrixSection header, required NatrixStructure content, required NatrixSection footer})
const

Properties

content NatrixStructure
final
final
hashCode int
The hash code for this object.
no setterinherited
final
isEmpty bool
Whether this NatrixSection contains actual content that should be displayed or not.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() List<NatrixText>
Returns a List of formatted NatrixText ready for output.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited