isEmpty property
Whether this NatrixSection contains actual content that should be displayed or not.
Implementation
@override
bool get isEmpty => header.isEmpty && content.isEmpty && footer.isEmpty;
Whether this NatrixSection contains actual content that should be displayed or not.
@override
bool get isEmpty => header.isEmpty && content.isEmpty && footer.isEmpty;