isEmpty property
Whether this NatrixSection contains actual content that should be displayed or not.
Implementation
@override
bool get isEmpty => tooltip.isEmpty && usage.isEmpty && description.isEmpty;
Whether this NatrixSection contains actual content that should be displayed or not.
@override
bool get isEmpty => tooltip.isEmpty && usage.isEmpty && description.isEmpty;