NatrixSection class abstract interface

A NatrixSection serves as an interface definition for objects that describe a section of text.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether this NatrixSection contains actual content that should be displayed or not.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format() List<NatrixText>
Returns a List of formatted NatrixText ready for output.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited