isEmpty property
bool
get
isEmpty
Whether this NatrixSection contains actual content that should be displayed or not.
Implementation
bool get isEmpty;
Whether this NatrixSection contains actual content that should be displayed or not.
bool get isEmpty;