NatrixStructure class

Implemented types

Constructors

NatrixStructure({required List<NatrixSection> sections, int padding = 1, int spacePrefix = 0})
const
NatrixStructure.empty()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether this NatrixSection contains actual content that should be displayed or not.
no setteroverride
padding int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<NatrixSection>
final
spacePrefix int
final

Methods

format() List<NatrixText>
Returns a List of formatted NatrixText ready for output.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited