footer property
NatrixSection
get
footer
The footer is the footer of a help request regarding a command.
Implementation
NatrixSection get footer;
The footer is the footer of a help request regarding a command.
NatrixSection get footer;