header property
NatrixSection
get
header
The header is the header of a helper request relating to a command.
Implementation
NatrixSection get header;
The header is the header of a helper request relating to a command.
NatrixSection get header;