syntax property
NatrixSection
get
syntax
The syntax is the syntax of a single command, including all its associated elements.
Implementation
NatrixSection get syntax;
The syntax is the syntax of a single command, including all its associated elements.
NatrixSection get syntax;