usage property
NatrixSection
get
usage
The usage is usually a single line that briefly outlines the command's syntax.
Implementation
NatrixSection get usage;
The usage is usually a single line that briefly outlines the command's syntax.
NatrixSection get usage;