core library
Classes
- NatrixBoolFlag
- Flag for Boolean values (bool).
- NatrixCallbackOptions
- Data passed to the NatrixCommandCallback necessary for working with the libraries internal and external definitions.
- NatrixChar
- Represents a single character string.
- NatrixCommand
- Immutable descriptor for a single node in a hierarchical CLI command tree.
- NatrixContext
- The NatrixContext is primarily an interface for applications outside the NatrixPipeline implementation to track the user's command input.
-
NatrixFlag<
T> - Typed command-line flag.
- NatrixParser
- The NatrixParser processes command-line input in a standard CLI syntax. This is the implementation of the user interface.
- NatrixParserFlag
- Represents an unprocessed flag read directly from the command-line input.
- NatrixParserOutput
- NatrixParserOutput holds the output of the process within NatrixParser.
- NatrixPipeline
- The NatrixPipeline is relatively simple and generally combines the subordinate steps, bringing together the data and the command to be executed.
- NatrixText
- Represents a multicharacter string with ansi escape sequence and filestream formatting.
- NatrixTextFlag
- Flag implementation for string values.
Enums
- NatrixColor
- Definition of the corresponding ANSI escape sequence values for their colors.
- NatrixStyle
- Definition of the corresponding ANSI escape sequence values for their styles.
Typedefs
-
NatrixCommandCallback
= FutureOr<
void> Function(NatrixCallbackOptions options) - Callback signature invoked when a NatrixCommand is selected during pipeline traversal.