set method

  1. @override
NatrixFlag<bool> set(
  1. bool value
)
override

Returns a new instance of this flag with the specified value.

Invoked internally to produce updated flag instances after parsing.

Implementation

@override
NatrixFlag<bool> set(bool value) =>
    NatrixBoolFlag(id: id, acronym: acronym, tooltip: tooltip, value: value);