NatrixCallbackOptions class
Data passed to the NatrixCommandCallback necessary for working with the libraries internal and external definitions.
Constructors
-
NatrixCallbackOptions({required NatrixCommand cmd, required List<
String> args, required Iterable<NatrixFlag> flags, required NatrixParserOutput parserOutput, required Iterable<NatrixFlag> globalFlags}) -
const
Properties
-
args
→ List<
String> -
A List of the parsed arguments from the command line.
final
- cmd → NatrixCommand
-
The NatrixCommand which owns this callback
and it's position in the cli tree after pipeline traversal.
final
-
flags
→ Iterable<
NatrixFlag> -
The flags of the command line input parsed from the predefined
NatrixFlags of their corresponding NatrixCommand which
got mapped in NatrixPipeline traversal.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getContext(
) → NatrixContext - Retrieves the NatrixContext of the callback-given-metadata.
-
getFlag<
T> (String name) → NatrixFlag< T> - Returns a NatrixFlag casted as the Type if the flag is available by it's identifier.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited