argumentTip property
The argumentTip is a word that describes the argument in help requests and briefly explains to the user what they should enter.
Implementation
final String argumentTip;
The argumentTip is a word that describes the argument in help requests and briefly explains to the user what they should enter.
final String argumentTip;