NatrixContext class
The NatrixContext is primarily an interface for applications outside the NatrixPipeline implementation to track the user's command input.
Constructors
-
NatrixContext({required NatrixCommand cmd, required NatrixParserOutput parserOutput, required Iterable<
NatrixFlag> globalFlags}) -
const
Properties
- cmd → NatrixCommand
-
The NatrixCommand called by the user.
final
-
globalFlags
→ Iterable<
NatrixFlag> -
globalFlags is a Iterable with elements
that may occur in
parserOutput.args.final - hashCode → int
-
The hash code for this object.
no setterinherited
- parserOutput → NatrixParserOutput
-
The output of the parsing process of the command line input,
which holds information related to the execution configuration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited