parserOutput property
The output of the parsing process of the command line input, which holds information related to the execution configuration.
Implementation
final NatrixParserOutput parserOutput;
The output of the parsing process of the command line input, which holds information related to the execution configuration.
final NatrixParserOutput parserOutput;