set abstract method
Returns a new instance of this flag with the specified value.
Invoked internally to produce updated flag instances after parsing.
Implementation
NatrixFlag<T> set(T value);
Returns a new instance of this flag with the specified value.
Invoked internally to produce updated flag instances after parsing.
NatrixFlag<T> set(T value);