NatrixParserFlag class
Represents an unprocessed flag read directly from the command-line input.
Constructors
- NatrixParserFlag(String tag, String val, bool isShort)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isShort → bool
-
Whether the flag was called in short
form (
-e) or in long form (--example);final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
The tag of the flag (the flag’s identifier or acronym),
specified on the command line (
-tor--test).final - val → String
-
A
stringvalue to be assigned to the flag call.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
String val) → NatrixParserFlag -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override