NatrixPipeline class final
The NatrixPipeline is relatively simple and generally combines the subordinate steps, bringing together the data and the command to be executed.
Constructors
-
NatrixPipeline({required List<
String> arguments, NatrixParser parser = const NatrixParser(), List<NatrixFlag> globalFlags = const []}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
NatrixCommand cmd) → FutureOr< void> - Determines which NatrixCommand of a tree will be executed by the arguments and applies these in parsed state to the command's NatrixCommandCallback.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited