set method

  1. @override
NatrixFlag<String> set(
  1. String value
)
override

Returns a new instance of this flag with the specified value.

Invoked internally to produce updated flag instances after parsing.

Implementation

@override
NatrixFlag<String> set(String value) =>
    NatrixTextFlag(id: id, acronym: acronym, tooltip: tooltip, value: value);