NatrixStdio class
Constructors
- NatrixStdio()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
newLine(
{NatrixText text = const NatrixText.empty(), NatrixStdoutSink? output}) → NatrixMount -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestInput(
{NatrixText prefix = const NatrixText.empty(), NatrixColor inputForegroundColor = .none, NatrixColor inputBackgroundColor = .none, NatrixStyle inputStyle = .none, bool hideInput = false}) → (String, NatrixMount) -
setLine(
{required NatrixMount mount, NatrixText text = const NatrixText.empty()}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
writeLines(
{List< NatrixText> lines = const [], NatrixStdoutSink? output}) → Iterable<NatrixMount>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override