theme library
Classes
- NatrixBlock
- A section of text that requires a heading and spans multiple lines.
- NatrixColumn
- NatrixDefaultTheme
- NatrixDocument
- NatrixHeader
- Defines the text section that is typically returned when requesting an application note for a NatrixCommand.
- NatrixLine
- NatrixSection
- A NatrixSection serves as an interface definition for objects that describe a section of text.
- NatrixStructure
- NatrixTheme
- The NatrixTheme class serves as an interface definition for a standard CLI theme. It can, of course, be extended and modified.