NatrixBlock class
A section of text that requires a heading and spans multiple lines.
For example, NatrixBlock is used for the section of text listing possible subcommands or applicable NatrixFlags.
- Implemented types
Constructors
- NatrixBlock({required NatrixText heading, required NatrixStructure content})
-
const
- NatrixBlock.empty()
-
An empty NatrixBlock with no content and no heading.
factory
Properties
- content → NatrixStructure
-
The lines below the heading that belong to this section of text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading → NatrixText
-
The heading of the text section.
final
- isEmpty → bool
-
Whether this NatrixSection contains actual content that should
be displayed or not.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
) → List< NatrixText> -
Returns a List of formatted NatrixText ready for output.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited