NatrixHeader class
Defines the text section that is typically returned when requesting an application note for a NatrixCommand.
- Implemented types
Constructors
- NatrixHeader({required NatrixSection tooltip, required NatrixText usage, required NatrixSection description})
-
const
Properties
- description → NatrixSection
-
A detailed description of the NatrixCommand to inform users
about how it works.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether this NatrixSection contains actual content that should
be displayed or not.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → NatrixSection
-
A brief description of the NatrixCommand.
final
- usage → NatrixText
-
A brief, structured overview of the possible and correct uses of the NatrixCommand.
final
Methods
-
format(
) → List< NatrixText> -
Returns a List of formatted NatrixText ready for output.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited