NatrixTheme class abstract
The NatrixTheme class serves as an interface definition for a standard CLI theme. It can, of course, be extended and modified.
However, it's recommended that every implementation supports the absolute minimum specified here.
- Implementers
Constructors
- NatrixTheme.of(NatrixContext context)
-
const
Properties
- commands → NatrixSection
-
commands is a section that lists applicable sub-NatrixCommands.
no setter
- context → NatrixContext
-
The NatrixContext for the current execution of the NatrixPipeline.
final
- flags → NatrixSection
-
flags is a section that lists applicable NatrixFlags.
no setter
-
The footer is the footer of a help request regarding a command.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → NatrixSection
-
The header is the header of a helper request relating to a command.
no setter
- root → NatrixSection
-
The root is the NatrixSection that is to be formatted and displayed
when a user either calls the application’s root command (provided this
does not already have a function and would simply displays a motd) or
when the root is accessed via the help command.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syntax → NatrixSection
-
The syntax is the syntax of a single command,
including all its associated elements.
no setter
- usage → NatrixSection
-
The usage is usually a single line
that briefly outlines the command's syntax.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited